@@ -3,10 +3,7 @@ from __future__ import absolute_import, print_function, unicode_literals
 import yaml
 import yamlish
 import test
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 test_data_list = [
   {
@@ -365,6 +362,7 @@ test_data_list = [
   },
 ]
 
+
 class TestReader(unittest.TestCase):  # IGNORE:C0111
     pass
 
